@@ -42,7 +42,7 @@ pub const USER_PORTFOLIO_PREFIX: usize = 227;
 pub const SPLU_LEN: usize = 161;
 
 /// The size of Turing account 
-pub const TURING_ACCOUNT_PREFIX:usize = 75;
+pub const TURING_MASHINE_ACCOUNT_PREFIX:usize = 75;
 
 /// The size of splu secondary state of Turing account 
 pub const SPLU_SECONDARY_STRUCT_LEN:usize = 1;
